#
# spec file for package AMF
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           AMF
Version:        1.4.35
Release:        1.3
Summary:        Advanced Media Framework (AMF) SDK
License:        MIT
URL:            https://gpuopen.com/advanced-media-framework/
Source:         %{name}-%{version}.tar
BuildArch:      noarch

%description
A lightweight, portable multimedia framework that abstracts away most of the
platform and API-specific details. %{name} is supported on the closed-source
AMDGPU-Pro driver.

%package        devel
Summary:        Development files for %{name}
Suggests:       AMF-docs

%description    devel
A lightweight, portable multimedia framework that abstracts away most of the
platform and API-specific details. %{name} is supported on the closed-source
AMDGPU-Pro driver.

The %{name}-devel package contains header files for developing
applications that use %{name}.

%package docs
Summary:        Additional Documentation for the Advanced Media Framework (AMF) SDK
Group:          Documentation/Other

%description docs
This package contains additional documentation provided for the
Advanced Media Framework (AMF) SDK.

%prep
%setup -q

%build

%install
install -dm755 %{buildroot}%{_includedir}/%{name}/components
install -dm755 %{buildroot}%{_includedir}/%{name}/core
install -Dm644 amf/public/include/components/*.h %{buildroot}%{_includedir}/%{name}/components
install -Dm644 amf/public/include/core/*.h %{buildroot}%{_includedir}/%{name}/core

%files devel
%license LICENSE.txt
%doc amf/doc/README.md
%{_includedir}/%{name}/

%files docs
%doc amf/doc/*

%changelog
* Sun Oct  6 2024 andrea.manzini@suse.com
- Update to version 1.4.35:
  * Define AMFPRI(d|ud|x)64 using the standard C++ format for C+11 and up
  * Define LPRI(d|ud|x)64 as Unicode (wide) versions of AMFPRI(d|ud|x)64
  * Move AMF_UNICODE into Platform.h
  * Add version to the directory and resulting file
  * Include root directory that matches file name
  * Create publish header action
  * Update VQ Enhancer API doc
  * Update HEVC API doc pdf
  * fix doc
  * Clarify PA LAB depth suggestion
  * Differentiate the AMF_NO_VTABLE based on the compiler
  * Fix const on return by value Variant values
  * Fix const on return by value AMF_DECLARE_IID()
  * Fix AMF string format sizes for 64-bit Linux
  * Don't cast amf_int64 when using a format string
  * Fix warning when _MSC_VER is not defined
  * Update PA Engine Type Documentation
  * Fix missing include (#276)
* Tue Jan 23 2024 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 1.4.33:
  * Added native DX12 support for encoding and PreAnalysis
  * Vulkan encoder became independent from Vulkan driver
  * Switched to public Vulkan Khronos extensions for decoder
  * AMF on Linux can now be used with AMD Pro Vulkan, and experimentally with RADV drivers
  * Improvements to sample presenters
  * Added new FRC component and API doc
  * Added new VQEnhancer API doc
  * Improvements and cleanup to sample presenters
  * Updated FFmpeg to 6.0
* Mon Nov 13 2023 ecsos@opensuse.org
- Update to version 1.4.30:
  * AMF v1.4.30 release
  * Fix missing enum value in AMF_Video_Encode_HEVC_API docs
  * Fix VulkanAMF.h compile when using C (#388)
  * Fix typo in profile level string (#371)
  * Encode API doc corrections
  * Add SmartAccess Video documentation
  * Update Linux distro prereqs for AMF v1.4.29
* Fri Mar 10 2023 Enrico Belleri <idesmi@protonmail.com>
- Exclude pdf and images
* Wed Mar  8 2023 Enrico Belleri <idesmi@protonmail.com>
- Update to version 1.4.29:
  * Added Smart Access Video for decoder and AVC / HEVC / AV1 encoders
  * New options for VQEnhancer and AV1 encoder components
  * Switched to Markdown based API docs which enable easier open source
    developer contributions
  * Added AV1 encoding support
  * Added 12-bit AV1 decoding
  * New VQEnhancer component
  * New AVC / HEVC encoder rate control methods
* Thu Jul 28 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to version 1.4.26:
  * New perceptual (PAQ) and temporal (TAQ) adaptive quantization modes
    for PreAnalysis
  * New high motion quality boost mode for PreAnalysis
  * New sharpness option for HQScaler
  * New low latency decoding option
  * New temporal SVC encoding options
* Wed Mar 23 2022 Enrico Belleri <idesmi@protonmail.com>
- initial package
